/**
/// ScrimpNet.Core Library
/// Copyright (c) 2005-2010
///
/// This module is Copyright (c) 2005-2010 Steve Powell
/// All rights reserved.
///
/// This library is free software; you can redistribute it and/or
/// modify it under the terms of the Microsoft Public License (Ms-PL)
/// 
/// This library is distributed in the hope that it will be
/// useful, but WITHOUT ANY WARRANTY; without even the implied
/// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
/// PURPOSE.  See theMicrosoft Public License (Ms-PL) License for more
/// details.
///
/// You should have received a copy of the Microsoft Public License (Ms-PL)
/// License along with this library; if not you may 
/// find it here: http://www.opensource.org/licenses/ms-pl.html
///
/// Steve Powell, spowell@scrimpnet.com
**/
using System;
using System.Collections.Generic;
using System.Text;

namespace ScrimpNet.Core.Net
{
    ///<summary>
    /// List of industry standandard file extensions, applications, and Mime Types.
    ///</summary>
    ///<remarks>
    /// autogenerated using Mime.MimeFormatEnumGenenerator and MimeTypes.xml.  Modify MimeTypes.xml and regenerate when adding new MimeTypes.
    ///</remarks>
    public enum MimeExtension
    {
        ///<summary>
        /// unknown or undefined (0)
        ///</summary>
        unknown = 0,
        ///<summary>
        /// Place holder for 'Image Not Found'(1)
        ///</summary>
        inf = 1,
        ///<summary>
        /// AutoCAD(application/acad)(2)
        ///</summary>
        dwg = 2,
        ///<summary>
        /// compressed archive(application/arj)(3)
        ///</summary>
        arj = 3,
        ///<summary>
        /// Astound(application/astound)(4)
        ///</summary>
        asd = 4,
        ///<summary>
        /// Astound(application/astound)(5)
        ///</summary>
        asn = 5,
        ///<summary>
        /// ClarisCAD(application/clariscad)(6)
        ///</summary>
        ccad = 6,
        ///<summary>
        /// Microsoft Excel(application/msexcel)(7)
        ///</summary>
        csv = 7,
        ///<summary>
        /// MATRA Prelude drafting(application/drafting)(8)
        ///</summary>
        drw = 8,
        ///<summary>
        /// DXF (AutoCAD)(application/dxf)(9)
        ///</summary>
        dxf = 9,
        ///<summary>
        /// SDRC I-DEAS (application/i-deas)(10)
        ///</summary>
        unv = 10,
        ///<summary>
        /// IGES graphics format(application/iges)(11)
        ///</summary>
        iges = 11,
        ///<summary>
        /// IGES graphics format(application/iges)(12)
        ///</summary>
        igs = 12,
        ///<summary>
        /// Java archive(application/java-archive)(13)
        ///</summary>
        jar = 13,
        ///<summary>
        /// Macintosh binary BinHex 4.0(application/mac-binhex40)(14)
        ///</summary>
        hqx = 14,
        ///<summary>
        /// Microsoft Access(application/msaccess)(15)
        ///</summary>
        mdb = 15,
        ///<summary>
        /// Microsoft Excel(application/msexcel)(16)
        ///</summary>
        xla = 16,
        ///<summary>
        /// Microsoft Excel(application/msexcel)(17)
        ///</summary>
        xls = 17,
        ///<summary>
        /// Microsoft Excel(application/msexcel)(18)
        ///</summary>
        xlt = 18,
        ///<summary>
        /// Microsoft Excel(application/msexcel)(19)
        ///</summary>
        xlw = 19,
        ///<summary>
        /// Microsoft PowerPoint(application/mspowerpoint)(20)
        ///</summary>
        pot = 20,
        ///<summary>
        /// Microsoft PowerPoint(application/mspowerpoint)(21)
        ///</summary>
        pps = 21,
        ///<summary>
        /// Microsoft PowerPoint(application/mspowerpoint)(22)
        ///</summary>
        ppt = 22,
        ///<summary>
        /// Microsoft Project(application/msproject)(23)
        ///</summary>
        mpp = 23,
        ///<summary>
        /// Microsoft Word(application/msword)(24)
        ///</summary>
        doc = 24,
        ///<summary>
        /// Microsoft Word(application/msword)(25)
        ///</summary>
        word = 25,
        ///<summary>
        /// Microsoft Word(application/msword)(26)
        ///</summary>
        w6w = 26,
        ///<summary>
        /// Microsoft Write(application/mswrite)(27)
        ///</summary>
        wri = 27,
        ///<summary>
        /// ODA(application/oda)(28)
        ///</summary>
        oda = 28,
        ///<summary>
        /// Adobe Acrobat(application/pdf)(29)
        ///</summary>
        pdf = 29,
        ///<summary>
        /// PostScript(application/postscript)(30)
        ///</summary>
        ai = 30,
        ///<summary>
        /// PostScript(application/postscript)(31)
        ///</summary>
        eps = 31,
        ///<summary>
        /// PostScript(application/postscript)(32)
        ///</summary>
        ps = 32,
        ///<summary>
        /// PTC Pro/ENGINEER(application/pro_eng)(33)
        ///</summary>
        part = 33,
        ///<summary>
        /// PTC Pro/ENGINEER(application/pro_eng)(34)
        ///</summary>
        prt = 34,
        ///<summary>
        /// Rich Text Format(application/rtf)(35)
        ///</summary>
        rtf = 35,
        ///<summary>
        /// SET (French CAD)(application/set)(36)
        ///</summary>
        set = 36,
        ///<summary>
        /// stereolithography(application/sla)(37)
        ///</summary>
        stl = 37,
        ///<summary>
        /// MATRA Prelude Solids(application/solids)(38)
        ///</summary>
        sol = 38,
        ///<summary>
        /// ISO-10303 STEP data(application/STEP)(39)
        ///</summary>
        st = 39,
        ///<summary>
        /// ISO-10303 STEP data(application/STEP)(40)
        ///</summary>
        step = 40,
        ///<summary>
        /// ISO-10303 STEP data(application/STEP)(41)
        ///</summary>
        stp = 41,
        ///<summary>
        /// VDA-FS Surface data(application/vda)(42)
        ///</summary>
        vda = 42,
        ///<summary>
        /// binary CPIO(application/x-bcpio)(43)
        ///</summary>
        bcpio = 43,
        ///<summary>
        /// POSIX CPIO(application/x-cpio)(44)
        ///</summary>
        cpio = 44,
        ///<summary>
        /// C-shell script(application/x-csh)(45)
        ///</summary>
        csh = 45,
        ///<summary>
        /// Macromedia Director(application/x-director)(46)
        ///</summary>
        dcr = 46,
        ///<summary>
        /// Macromedia Director(application/x-director)(47)
        ///</summary>
        dir = 47,
        ///<summary>
        /// Macromedia Director(application/x-director)(48)
        ///</summary>
        dxr = 48,
        ///<summary>
        /// TeX DVI(application/x-dvi)(49)
        ///</summary>
        dvi = 49,
        ///<summary>
        /// AutoCAD(application/x-dwf)(50)
        ///</summary>
        dwf = 50,
        ///<summary>
        /// GNU tar(application/x-gtar)(51)
        ///</summary>
        gtar = 51,
        ///<summary>
        /// GNU ZIP(application/x-gzip)(52)
        ///</summary>
        gz = 52,
        ///<summary>
        /// NCSA HDF Data File(application/x-hdf)(53)
        ///</summary>
        hdf = 53,
        ///<summary>
        /// JavaScript(application/x-javascript)(54)
        ///</summary>
        js = 54,
        ///<summary>
        /// LaTeX source(application/x-latex)(55)
        ///</summary>
        latex = 55,
        ///<summary>
        /// Macintosh compressed(application/x-macbinary)(56)
        ///</summary>
        bin = 56,
        ///<summary>
        /// FrameMaker MIF (application/x-mif)(57)
        ///</summary>
        mif = 57,
        ///<summary>
        /// Unidata netCDF(application/x-netcdf)(58)
        ///</summary>
        cdf = 58,
        ///<summary>
        /// Unidata netCDF(application/x-netcdf)(59)
        ///</summary>
        nc = 59,
        ///<summary>
        /// Bourne shell script(application/x-sh)(60)
        ///</summary>
        sh = 60,
        ///<summary>
        /// shell archive(application/x-shar)(61)
        ///</summary>
        shar = 61,
        ///<summary>
        /// Macromedia Shockwave(application/x-shockwave-flash)(62)
        ///</summary>
        swf = 62,
        ///<summary>
        /// StuffIt archive(application/x-stuffit)(63)
        ///</summary>
        sit = 63,
        ///<summary>
        /// SVR4 CPIO(application/x-sv4cpio)(64)
        ///</summary>
        sv4cpio = 64,
        ///<summary>
        /// SVR4 CPIO with CRC(application/x-sv4crc)(65)
        ///</summary>
        sv4crc = 65,
        ///<summary>
        /// 4.3BSD tar format(application/x-tar)(66)
        ///</summary>
        tar = 66,
        ///<summary>
        /// TCL script(application/x-tcl)(67)
        ///</summary>
        tcl = 67,
        ///<summary>
        /// TeX source(application/x-tex)(68)
        ///</summary>
        tex = 68,
        ///<summary>
        /// Texinfo (Emacs)(application/x-texinfo)(69)
        ///</summary>
        texi = 69,
        ///<summary>
        /// Texinfo (Emacs)(application/x-texinfo)(70)
        ///</summary>
        texinfo = 70,
        ///<summary>
        /// Troff(application/x-troff)(71)
        ///</summary>
        roff = 71,
        ///<summary>
        /// Troff(application/x-troff)(72)
        ///</summary>
        t = 72,
        ///<summary>
        /// Troff(application/x-troff)(73)
        ///</summary>
        tr = 73,
        ///<summary>
        /// Troff with MAN macros(application/x-troff-man)(74)
        ///</summary>
        man = 74,
        ///<summary>
        /// Troff with ME macros(application/x-troff-me)(75)
        ///</summary>
        me = 75,
        ///<summary>
        /// Troff with MS macros(application/x-troff-ms)(76)
        ///</summary>
        ms = 76,
        ///<summary>
        /// POSIX tar format(application/x-ustar)(77)
        ///</summary>
        ustar = 77,
        ///<summary>
        /// WAIS source(application/x-wais-source)(78)
        ///</summary>
        src = 78,
        ///<summary>
        /// Microsoft Windows help(application/x-winhelp)(79)
        ///</summary>
        hlp = 79,
        ///<summary>
        /// ZIP archive(application/zip)(80)
        ///</summary>
        zip = 80,
        ///<summary>
        /// BASIC audio (u-law)(audio/basic)(81)
        ///</summary>
        au = 81,
        ///<summary>
        /// BASIC audio (u-law)(audio/basic)(82)
        ///</summary>
        snd = 82,
        ///<summary>
        /// MIDI(audio/midi)(83)
        ///</summary>
        mid = 83,
        ///<summary>
        /// MIDI(audio/midi)(84)
        ///</summary>
        midi = 84,
        ///<summary>
        /// AIFF audio(audio/x-aiff)(85)
        ///</summary>
        aif = 85,
        ///<summary>
        /// AIFF audio(audio/x-aiff)(86)
        ///</summary>
        aifc = 86,
        ///<summary>
        /// AIFF audio(audio/x-aiff)(87)
        ///</summary>
        aiff = 87,
        ///<summary>
        /// MPEG audio(audio/x-mpeg)(88)
        ///</summary>
        mp3 = 88,
        ///<summary>
        /// RealAudio(audio/x-pn-realaudio)(89)
        ///</summary>
        ra = 89,
        ///<summary>
        /// RealAudio(audio/x-pn-realaudio)(90)
        ///</summary>
        ram = 90,
        ///<summary>
        /// RealAudio plug-in(audio/x-pn-realaudio-plugin)(91)
        ///</summary>
        rpm = 91,
        ///<summary>
        /// Voice(audio/x-voice)(92)
        ///</summary>
        voc = 92,
        ///<summary>
        /// Microsoft Windows WAVE audio(audio/x-wav)(93)
        ///</summary>
        wav = 93,
        ///<summary>
        /// Bitmap(image/bmp)(94)
        ///</summary>
        bmp = 94,
        ///<summary>
        /// GIF image(image/gif)(95)
        ///</summary>
        gif = 95,
        ///<summary>
        /// Image Exchange Format(image/ief)(96)
        ///</summary>
        ief = 96,
        ///<summary>
        /// JPEG image(image/jpeg)(97)
        ///</summary>
        jpe = 97,
        ///<summary>
        /// JPEG image(image/jpeg)(98)
        ///</summary>
        jpeg = 98,
        ///<summary>
        /// JPEG image(image/jpeg)(99)
        ///</summary>
        jpg = 99,
        ///<summary>
        /// Macintosh PICT(image/pict)(100)
        ///</summary>
        pict = 100,
        ///<summary>
        /// Portable Network Graphic(image/png)(101)
        ///</summary>
        png = 101,
        ///<summary>
        /// TIFF image(image/tiff)(102)
        ///</summary>
        tif = 102,
        ///<summary>
        /// TIFF image(image/tiff)(103)
        ///</summary>
        tiff = 103,
        ///<summary>
        /// CMU raster(image/x-cmu-raster)(104)
        ///</summary>
        ras = 104,
        ///<summary>
        /// PBM Anymap format(image/x-portable-anymap)(105)
        ///</summary>
        pnm = 105,
        ///<summary>
        /// PBM Bitmap format(image/x-portable-bitmap)(106)
        ///</summary>
        pbm = 106,
        ///<summary>
        /// PBM Graymap format(image/x-portable-graymap)(107)
        ///</summary>
        pgm = 107,
        ///<summary>
        /// PBM Pixmap format(image/x-portable-pixmap)(108)
        ///</summary>
        ppm = 108,
        ///<summary>
        /// RGB image(image/x-rgb)(109)
        ///</summary>
        rgb = 109,
        ///<summary>
        /// X Bitmap(image/x-xbitmap)(110)
        ///</summary>
        xbm = 110,
        ///<summary>
        /// X Pixmap(image/x-xpixmap)(111)
        ///</summary>
        xpm = 111,
        ///<summary>
        /// X Window System dump(image/x-xwindowdump)(112)
        ///</summary>
        xwd = 112,
        ///<summary>
        /// GNU ZIP archive(multipart/x-gzip)(113)
        ///</summary>
        gzip = 113,
        ///<summary>
        /// HTML(text/html)(114)
        ///</summary>
        htm = 114,
        ///<summary>
        /// HTML(text/html)(115)
        ///</summary>
        html = 115,
        ///<summary>
        /// plain text(text/plain)(116)
        ///</summary>
        C = 116,
        ///<summary>
        /// plain text(text/plain)(117)
        ///</summary>
        cc = 117,
        ///<summary>
        /// plain text(text/plain)(118)
        ///</summary>
        h = 118,
        ///<summary>
        /// plain text(text/plain)(119)
        ///</summary>
        txt = 119,
        ///<summary>
        /// MIME Richtext(text/richtext)(120)
        ///</summary>
        rtx = 120,
        ///<summary>
        /// text with tabs(text/tab-separated-values)(121)
        ///</summary>
        tsv = 121,
        ///<summary>
        /// Structurally Enhanced Text(text/x-setext)(122)
        ///</summary>
        etx = 122,
        ///<summary>
        /// SGML(text/x-sgml)(123)
        ///</summary>
        sgm = 123,
        ///<summary>
        /// SGML(text/x-sgml)(124)
        ///</summary>
        sgml = 124,
        ///<summary>
        /// MPEG video(video/mpeg)(125)
        ///</summary>
        mpe = 125,
        ///<summary>
        /// MPEG video(video/mpeg)(126)
        ///</summary>
        mpeg = 126,
        ///<summary>
        /// MPEG video(video/mpeg)(127)
        ///</summary>
        mpg = 127,
        ///<summary>
        /// Microsoft Windows video(video/msvideo)(128)
        ///</summary>
        avi = 128,
        ///<summary>
        /// QuickTime video(video/quicktime)(129)
        ///</summary>
        mov = 129,
        ///<summary>
        /// QuickTime video(video/quicktime)(130)
        ///</summary>
        qt = 130,
        ///<summary>
        /// VDO streaming video(video/vdo)(131)
        ///</summary>
        vdo = 131,
        ///<summary>
        /// VIVO streaming video(video/vivo)(132)
        ///</summary>
        viv = 132,
        ///<summary>
        /// VIVO streaming video(video/vivo)(133)
        ///</summary>
        vivo = 133,
        ///<summary>
        /// SGI Movieplayer format(video/x-sgi-movie)(134)
        ///</summary>
        movie = 134,
        ///<summary>
        /// CoolTalk(x-conference/x-cooltalk)(135)
        ///</summary>
        ice = 135,
        ///<summary>
        /// Virtual reality(x-world/x-svr)(136)
        ///</summary>
        svr = 136,
        ///<summary>
        /// VRML Worlds(x-world/x-vrml)(137)
        ///</summary>
        wrl = 137,
        ///<summary>
        /// Virtual reality(x-world/x-vrt)(138)
        ///</summary>
        vrt = 138,
        ///<summary>
        /// Microsoft Office Word 2007 document(application/vnd.openxmlformats-officedocument.wordprocessingml.document)(139)
        ///</summary>
        docx = 139,
        ///<summary>
        /// Office Word 2007 macro-enabled document(application/vnd.ms-word.document.macroEnabled.12)(140)
        ///</summary>
        docm = 140,
        ///<summary>
        /// Office Word 2007 template(application/vnd.openxmlformats-officedocument.wordprocessingml.template)(141)
        ///</summary>
        dotx = 141,
        ///<summary>
        /// Office Word 2007 macro-enabled document template(application/vnd.ms-word.template.macroEnabled.12)(142)
        ///</summary>
        dotm = 142,
        ///<summary>
        /// Microsoft Office Excel 2007 workbook(application/vnd.openxmlformats-officedocument.spreadsheetml.sheet)(143)
        ///</summary>
        xlsx = 143,
        ///<summary>
        /// Office Excel 2007 macro-enabled workbook(application/vnd.ms-excel.sheet.macroEnabled.12)(144)
        ///</summary>
        xlsm = 144,
        ///<summary>
        /// Office Excel 2007 template(application/vnd.openxmlformats-officedocument.spreadsheetml.template)(145)
        ///</summary>
        xltx = 145,
        ///<summary>
        /// Office Excel 2007 macro-enabled workbook template(application/vnd.ms-excel.template.macroEnabled.12)(146)
        ///</summary>
        xltm = 146,
        ///<summary>
        /// Office Excel 2007 binary workbook(application/vnd.ms-excel.sheet.binary.macroEnabled.12)(147)
        ///</summary>
        xlsb = 147,
        ///<summary>
        /// Office Excel 2007 add-in(application/vnd.ms-excel.addin.macroEnabled.12)(148)
        ///</summary>
        xlam = 148,
        ///<summary>
        /// Microsoft Office PowerPoint 2007 presentation(application/vnd.openxmlformats-officedocument.presentationml.presentation)(149)
        ///</summary>
        pptx = 149,
        ///<summary>
        /// Office PowerPoint 2007 macro-enabled presentation(application/vnd.ms-powerpoint.presentation.macroEnabled.12)(150)
        ///</summary>
        pptm = 150,
        ///<summary>
        /// Office PowerPoint 2007 slide show(application/vnd.openxmlformats-officedocument.presentationml.slideshow)(151)
        ///</summary>
        ppsx = 151,
        ///<summary>
        /// Office PowerPoint 2007 macro-enabled slide show(application/vnd.ms-powerpoint.slideshow.macroEnabled.12)(152)
        ///</summary>
        ppsm = 152,
        ///<summary>
        /// Office PowerPoint 2007 template(application/vnd.openxmlformats-officedocument.presentationml.template)(153)
        ///</summary>
        potx = 153,
        ///<summary>
        /// Office PowerPoint 2007 macro-enabled presentation template(application/vnd.ms-powerpoint.template.macroEnabled.12)(154)
        ///</summary>
        potm = 154,
        ///<summary>
        /// Office PowerPoint 2007 add-in(application/vnd.ms-powerpoint.addin.macroEnabled.12)(155)
        ///</summary>
        ppam = 155,
        ///<summary>
        /// Office PowerPoint 2007 slide(application/vnd.openxmlformats-officedocument.presentationml.slide)(156)
        ///</summary>
        sldx = 156,
        ///<summary>
        /// Office PowerPoint 2007 macro-enabled slide(application/vnd.ms-powerpoint.slide.macroEnabled.12)(157)
        ///</summary>
        sldm = 157,
        ///<summary>
        /// Microsoft Office OneNote 2007 section(application/onenote)(158)
        ///</summary>
        one = 158,
        ///<summary>
        /// Office OneNote 2007 TOC(application/onenote)(159)
        ///</summary>
        onetoc2 = 159,
        ///<summary>
        /// Office OneNote 2007 temporary file(application/onenote)(160)
        ///</summary>
        onetmp = 160,
        ///<summary>
        /// Office OneNote 2007 package(application/onenote)(161)
        ///</summary>
        onepkg = 161,
        ///<summary>
        /// 2007 Office system release theme(application/vnd.ms-officetheme)(162)
        ///</summary>
        thmx = 162,
    }
}
